plot_ensemble_mean <- function(recipe, fcst, outdir) {

  ## TODO: Add 'anomaly' to plot title
  # Abort if frequency is daily
  if (recipe$Analysis$Variables$freq == "daily_mean") {
    stop("Visualization functions not yet implemented for daily data.")
  }

  latitude <- fcst$coords$lat
  longitude <- fcst$coords$lon
  archive <- get_archive(recipe)
  system_name <- archive$System[[recipe$Analysis$Datasets$System$name]]$name
  start_date <- paste0(recipe$Analysis$Time$fcst_year,
                       recipe$Analysis$Time$sdate)
  # Compute ensemble mean
  ensemble_mean <- s2dv::MeanDims(fcst$data, 'ensemble')
  # Loop over variable dimension
  for (var in 1:fcst$dims[['var']]) {
    variable <- fcst$attrs$Variable$varName[[var]]
    units <- fcst$attrs$Variable$metadata[[variable]]$units
    var_ens_mean <- ClimProjDiags::Subset(ensemble_mean,
                                          along = c("dat", "var",
                                                    "sday", "sweek"),
                                          indices = list(1, var, 1, 1),
                                          drop = 'selected')

    var_ens_mean <- Reorder(var_ens_mean, c("syear",
                                            "time",
                                            "longitude",
                                            "latitude"))
    ## TODO: Redefine column colors, possibly depending on variable
    if (variable == 'prlr') {
      palette = "BrBG"
      rev = F
    } else {
      palette = "RdBu"
      rev = T
    }
    # Define brks, centered on in the case of anomalies
    ##
    if (grepl("anomaly",
              fcst$attrs$Variable$metadata[[variable]]$long_name)) {
      variable <- paste(variable, "anomaly")
      max_value <- max(abs(var_ens_mean))
      ugly_intervals <- seq(-max_value, max_value, max_value/20)
      brks <- pretty(ugly_intervals, n = 12, min.n = 8)
    } else {
      brks <- pretty(range(var_ens_mean, na.rm = T), n = 15, min.n = 8)
    }
    cols <- grDevices::hcl.colors(length(brks) - 1, palette, rev = rev)
    options(bitmapType = "cairo")

    for (i_syear in start_date) {
      # Define name of output file and titles
      i_var_ens_mean <- var_ens_mean[which(start_date == i_syear), , , ]
      outfile <- paste0(outdir[[var]], "forecast_ensemble_mean-", i_syear, ".png")
      toptitle <- paste("Forecast Ensemble Mean -", variable, "-", system_name,
                        "- Initialization:", i_syear)
      months <- lubridate::month(fcst$attrs$Dates[1, 1, which(start_date == i_syear), ],
                                 label = T, abb = F)
      titles <- as.vector(months)
      # Plots
      PlotLayout(PlotEquiMap, c('longitude', 'latitude'),
                 i_var_ens_mean, longitude, latitude,
                 filled.continents = F,
                 toptitle = toptitle,
                 title_scale = 0.6,
                 titles = titles,
                 units = units,
                 cols = cols,
                 brks = brks,
                 fileout = outfile,
                 bar_label_digits = 4,
                 bar_extra_margin = rep(0.7, 4),
                 bar_label_scale = 1.5,
                 axes_label_scale = 1.3)
    }
    info(recipe$Run$logger,
         "##### FCST ENSEMBLE MEAN PLOT SAVED TO OUTPUT DIRECTORY #####")
  }
}
